# hypixel-py
Python wrapper for the Hypixel API. Includes QOL features such as WLR and KDR precalculated, still very much a WIP in very early stages of development.

# Features
- Backwards compatible with the Hypixel API
- WLR and KDR for the following modes:
    - UHC
    - Bedwars
    - Skywars
    - Duels
- Precalculated values
    - Network level
    - Total wins for games
- Duels mode have prestiges precalculated
- Consolidation of values that are split
    - Ranks
    - Names
- Includes Mojang API
- Includes sweting's NoSnipe Overlay blacklist

